@@ -43,10 +43,13 @@ describe 'horizon' do
 
       it 'configures apache' do
         is_expected.to contain_class('horizon::wsgi::apache').with({
-          :servername    => 'some.host.tld',
-          :listen_ssl    => false,
-          :extra_params  => {},
-          :redirect_type => 'permanent',
+          :servername        => 'some.host.tld',
+          :listen_ssl        => false,
+          :wsgi_processes    => facts[:os_workers],
+          :wsgi_threads      => '1',
+          :extra_params      => {},
+          :redirect_type     => 'permanent',
+          :access_log_format => false,
         })
       end
 
@@ -62,7 +65,7 @@ describe 'horizon' do
           'HORIZON_CONFIG["images_panel"] = "legacy"',
           "SECRET_KEY = 'elj1IWiLoWHgcyYxFVLj7cM5rGOOxWl0'",
           'OPENSTACK_KEYSTONE_URL = "http://127.0.0.1:5000"',
-          'OPENSTACK_KEYSTONE_DEFAULT_ROLE = "_member_"',
+          'OPENSTACK_KEYSTONE_DEFAULT_ROLE = "member"',
           "    'can_set_mount_point': True,",
           "    'can_set_password': False,",
           "    'enable_distributed_router': False,",
@@ -106,6 +109,7 @@ describe 'horizon' do
           :openstack_endpoint_type        => 'internalURL',
           :secondary_endpoint_type        => 'ANY-VALUE',
           :django_debug                   => true,
+          :site_branding                  => 'mysite',
           :api_result_limit               => 4682,
           :compress_offline               => false,
           :hypervisor_options             => {'can_set_mount_point' => false, 'can_set_password' => true },
@@ -116,6 +120,8 @@ describe 'horizon' do
                                             'supported_provider_types' => ['flat', 'vxlan'], 'supported_vnic_types' => ['*'], 'default_ipv4_subnet_pool_label' => 'None', },
           :instance_options               => {'disable_image' => true, 'disable_instance_snapshot' => true, 'disable_volume' => true, 'disable_volume_snapshot' => true, 'create_volume' => false },
           :file_upload_temp_dir           => '/var/spool/horizon',
+          :wsgi_processes                 => '30',
+          :wsgi_threads                   => '5',
           :secure_cookies                 => true,
           :api_versions                   => {'identity' => 2.0},
           :keystone_multidomain_support   => true,
@@ -139,6 +145,7 @@ describe 'horizon' do
       it 'generates local_settings.py' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
           'DEBUG = True',
+          "SITE_BRANDING = 'mysite'",
           "ALLOWED_HOSTS = ['some.host.tld', ]",
           "SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')",
           'CSRF_COOKIE_SECURE = True',
@@ -242,6 +249,23 @@ describe 'horizon' do
       it { is_expected.to contain_exec('refresh_horizon_django_compress') }
     end
 
+    context 'with overridden parameters and cache_server_url' do
+      before do
+        params.merge!({
+          :cache_server_url => 'redis://:password@10.0.0.1:6379/1',
+        })
+      end
+
+      it 'generates local_settings.py' do
+        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
+          "        'LOCATION': 'redis://:password@10.0.0.1:6379/1',",
+        ])
+      end
+
+      it { is_expected.to contain_exec('refresh_horizon_django_cache') }
+      it { is_expected.to contain_exec('refresh_horizon_django_compress') }
+    end
+
     context 'installs python memcache library when cache_backend is set to memcache' do
       before do
         params.merge!({
@@ -257,6 +281,29 @@ describe 'horizon' do
       }
     end
 
+    context 'does not install python memcache when manage_memcache_package set to false' do
+      before do
+        params.merge!( :cache_backend           => 'django.core.cache.backends.memcached.MemcachedCache',
+                       :manage_memcache_package => false )
+      end
+
+      it { is_expected.not_to contain_package('python-memcache') }
+    end
+
+    context 'with custom wsgi options' do
+      before do
+        params.merge!( :wsgi_processes    => '30',
+                       :wsgi_threads      => '5',
+                       :access_log_format => 'common' )
+      end
+
+      it { should contain_class('horizon::wsgi::apache').with(
+        :wsgi_processes    => '30',
+        :wsgi_threads      => '5',
+        :access_log_format => 'common',
+      )}
+    end
+
     context 'with vhost_extra_params' do
       before do
         params.merge!({
@@ -628,6 +675,26 @@ describe 'horizon' do
         ])
       end
     end
+
+    context 'with keystone_domain_choices' do
+      before do
+        params.merge!({
+          :keystone_domain_choices  => [
+            {'name' => 'default', 'display' => 'The default domain'},
+            {'name' => 'LDAP', 'display' => 'The LDAP Catalog'},
+          ],
+        })
+      end
+      it 'sets OPENSTACK_KEYSTONE_DOMAIN_DROPDOWN in local_settings.py' do
+        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
+          'OPENSTACK_KEYSTONE_DOMAIN_DROPDOWN = True',
+          'OPENSTACK_KEYSTONE_DOMAIN_CHOICES = (',
+          "    ('default', 'The default domain'),",
+          "    ('LDAP', 'The LDAP Catalog'),",
+          ')',
+        ])
+      end
+    end
   end
 
   shared_examples_for 'horizon on RedHat' do
@@ -653,7 +720,8 @@ describe 'horizon' do
       let (:facts) do
         facts.merge!(OSDefaults.get_facts({
           :fqdn           => 'some.host.tld',
-          :concat_basedir => '/var/lib/puppet/concat'
+          :concat_basedir => '/var/lib/puppet/concat',
+          :os_workers     => '6'
         }))
       end
 
@@ -672,7 +740,7 @@ describe 'horizon' do
               :package_name     => 'openstack-dashboard',
               :root_url         => '/horizon',
               :root_path        => '/var/lib/openstack-dashboard',
-              :memcache_package => 'python-memcache',
+              :memcache_package => 'python3-memcache',
             }
           end
         when 'RedHat'
